Skip to content

Commit c9dc62d

Browse files
committed
Update reading kernels
1 parent 08d7c75 commit c9dc62d

1 file changed

Lines changed: 3 additions & 4 deletions

File tree

GPU/GPUbenchmark/cuda/Kernels.cu

Lines changed: 3 additions & 4 deletions
Original file line numberDiff line numberDiff line change
@@ -91,12 +91,11 @@ __global__ void readChunkMBKernel(
9191
chunk_type* results,
9292
size_t chunkSize)
9393
{
94+
chunk_type sink{0};
9495
for (int i = blockIdx.x * blockDim.x + threadIdx.x; i < chunkSize; i += blockDim.x * gridDim.x) {
95-
if (chunkPtr[i] == static_cast<chunk_type>(1)) { // actual read operation is performed here
96-
results[chunkId] += chunkPtr[i]; // this case should never happen and waves should be always in sync
97-
printf("Should never happen\n");
98-
}
96+
sink += chunkPtr[i];
9997
}
98+
results[chunkId] = sink;
10099
}
101100

102101
// Write

0 commit comments

Comments
 (0)